@@ -5,8 +5,7 @@
 import os
 import sys
 # local [--with=<key,value> ...]
-from projy import projy_style, projy_error, projy_info
-from projy import PROJY_DIR, PROJY_PROJ, PROJY_FILE
+from projy.TerminalView import *
 
 
 def docopt_arguments():
@@ -41,24 +40,24 @@ def template_name_from_class_name(class_name):
 
 def run_list():
     """ Print the list of all available templates. """
-    print(projy_info("These are the available templates:"))
+    term = TerminalView()
+    term.print_info("These are the available templates:")
     import pkgutil, projy.templates
     pkgpath = os.path.dirname(projy.templates.__file__)
     templates = [name for _, name, _ in pkgutil.iter_modules([pkgpath])]
     for name in templates:
         # the father of all templates, not a real usable one
         if (name != 'ProjyTemplate'):
-            print('\t' + projy_style(template_name_from_class_name(name),
-                                     PROJY_PROJ))
+            term.print_info(term.text_in_color(template_name_from_class_name(name), TERM_PINK))
 
 
 def run_info(template):
     """ Print information about a specific template. """
     template.project_name = 'TowelStuff' # fake project name, always the same
     name = template_name_from_class_name(template.__class__.__name__)
-    print(projy_info("Content of template " +
-          projy_style(name, PROJY_PROJ) +
-          " with an example project name 'TowelStuff':"))
+    term = TerminalView()
+    term.print_info("Content of template {0} with an example project " \
+          "named 'TowelStuff':".format(term.text_in_color(name, TERM_GREEN)))
 
     dir_name = None
     for file_info in sorted(template.files(), key=lambda dir: dir[0]):
@@ -70,23 +69,23 @@ def run_info(template):
         if file_info[2]:
             template_name = '\t\t - ' + file_info[2]
         if (directory != dir_name):
-            print('\n\t' + projy_style(directory + '/', PROJY_DIR))
+            term.print_info('\n\t' + term.text_in_color(directory + '/', TERM_PINK))
             dir_name = directory
 
-        print('\t\t' + projy_style(file_name, PROJY_FILE) + template_name)
+        term.print_info('\t\t' + term.text_in_color(file_name, TERM_YELLOW) + template_name)
 
     # print substitutions
     try:
         subs = template.substitutes().keys()
         if len(subs) > 0:
             subs.sort()
-            print('\n' + projy_info("Included substitutions are: "))
+            term.print_info("\nIncluded substitutions are: ")
             max_len = 0
             for key in subs:
                 if max_len < len(key):
                     max_len = len(key)
             for key in subs:
-                print("\t{0:{1}} -> {2}".
+                term.print_info("\t{0:{1}} -> {2}".
                 format(key, max_len, template.substitutes()[key]))
     except AttributeError:
         pass
@@ -95,24 +94,26 @@ def run_info(template):
 def template_class_from_name(name):
     """ Return the template class object from agiven name. """
     # import the right template module
+    term = TerminalView()
     template_name = name + 'Template'
     try:
         __import__('projy.templates.' + template_name)
         template_mod = sys.modules['projy.templates.' + template_name]
     except ImportError:
-        sys.exit(projy_error("Unable to find {0}".format(name)))
+        term.print_error_and_exit("Unable to find {0}".format(name))
 
     # import the class from the module
     try:
         template_class = getattr(template_mod, template_name)
     except AttributeError:
-        sys.exit(projy_error("Unable to create a template {0}".format(name)))
+        term.print_error_and_exit("Unable to create a template {0}".format(name))
     return template_class()
 
 
 def execute():
     """ Main function. """
     args = docopt_arguments()
+    term = TerminalView()
 
     # print list of installed templates
     if args['--list']:
@@ -128,11 +129,11 @@ def execute():
         if args['<template>']:
             run_info(template)
         else:
-            sys.exit(projy_error("Please specify a template"))
+            term.print_error_and_exit("Please specify a template")
         return
 
     # launch the template
     template.create(args['<project>'],
                     args['<template>'],
                     args['<substitution>'])
-    print(projy_info("Done!"))
+    term.print_info("Done!")
